==> shellcheck-0.4.6-5-i686.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.4.6
id: ShellCheck-0.4.6-cUsqQJtdwX8Bhq9TExgTO
key: ShellCheck-0.4.6-cUsqQJtdwX8Bhq9TExgTO
license: GPL-3
maintainer: vidar@vidarholen.net
homepage: http://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
author: Vidar Holen
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.Format
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
abi: 2b0686298cfbc498726d634bbb43620e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ShellCheck-0.4.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/ShellCheck-0.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/ShellCheck-0.4.6
hs-libraries: HSShellCheck-0.4.6-cUsqQJtdwX8Bhq9TExgTO
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq base-4.9.1.0
    containers-0.5.7.1 directory-1.3.0.0
    json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR process-1.4.3.0
    regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.4.6-6-i686.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.4.6
id: ShellCheck-0.4.6-7Mm4gxgDWBT4rmsKMxg6MF
key: ShellCheck-0.4.6-7Mm4gxgDWBT4rmsKMxg6MF
license: GPL-3
maintainer: vidar@vidarholen.net
homepage: http://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
author: Vidar Holen
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.Format
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
abi: d04dcca7597b9f781636f0bff078dfa1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ShellCheck-0.4.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/ShellCheck-0.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/ShellCheck-0.4.6
hs-libraries: HSShellCheck-0.4.6-7Mm4gxgDWBT4rmsKMxg6MF
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq base-4.9.1.0
    containers-0.5.7.1 directory-1.3.0.0
    json-0.9.1-C2FDZAxuh5hCIxQmYtJQ5P mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR process-1.4.3.0
    regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
